==> sight_20.0.0.orig.tar.gz: sight-20.0.0/modules/core/gui/src/gui/action/SDoNothing.cpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2018 IRCAD France
 * Copyright (C) 2012-2018 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "gui/action/SDoNothing.hpp"

#include <fwCore/base.hpp>

#include <fwServices/macros.hpp>

namespace gui
{
namespace action
{
fwServicesRegisterMacro( ::fwGui::IActionSrv, ::gui::action::SDoNothing );

SDoNothing::SDoNothing() noexcept
{
}

//-----------------------------------------------------------------------------

SDoNothing::~SDoNothing() noexcept
{
}

//-----------------------------------------------------------------------------

void SDoNothing::configuring()
{
    this->initialize();
}

//-----------------------------------------------------------------------------

void SDoNothing::starting()
{
    SLM_TRACE_FUNC();
    this->actionServiceStarting();
}

//-----------------------------------------------------------------------------

void SDoNothing::stopping()
{
    SLM_TRACE_FUNC();
    this->actionServiceStopping();
}

//-----------------------------------------------------------------------------

void SDoNothing::updating()
{
    SLM_TRACE_FUNC();
}

//-----------------------------------------------------------------------------

void SDoNothing::info(std::ostream& _sstream )
{
    _sstream << "Nothing Action" << std::endl;
}

}
}

==> sight_20.2.0.orig.tar.gz: sight-20.2.0/modules/core/gui/src/gui/action/SDoNothing.cpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2020 IRCAD France
 * Copyright (C) 2012-2020 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "gui/action/SDoNothing.hpp"

#include <fwCore/base.hpp>

#include <fwServices/macros.hpp>

namespace gui
{
namespace action
{
fwServicesRegisterMacro( ::fwGui::IActionSrv, ::gui::action::SDoNothing )

SDoNothing::SDoNothing() noexcept
{
}

//-----------------------------------------------------------------------------

SDoNothing::~SDoNothing() noexcept
{
}

//-----------------------------------------------------------------------------

void SDoNothing::configuring()
{
    this->initialize();
}

//-----------------------------------------------------------------------------

void SDoNothing::starting()
{
    this->actionServiceStarting();
}

//-----------------------------------------------------------------------------

void SDoNothing::stopping()
{
    this->actionServiceStopping();
}

//-----------------------------------------------------------------------------

void SDoNothing::updating()
{
}

//-----------------------------------------------------------------------------

void SDoNothing::info(std::ostream& _sstream )
{
    _sstream << "Nothing Action" << std::endl;
}

}
}
